// Painter MUX

// (c) J. Dean Brock, 2004
// Department of Computer Science
// University of North Carolina at Asheville


package edu.unca.cs.LabAids;

/**
 * The Painter MUX allows several different graphical
 * functions to be painted in a single panel.
 */
public class PainterMux extends javax.swing.JPanel {
    
    // Number of painters
    private int numPainters ;
    // Panel and buttons for selecting functions
    private javax.swing.JScrollPane  objectScrollBar ;
    private javax.swing.ButtonGroup objectButtonGroup ;
    private javax.swing.JPanel objectButtonPanel ;
    
    // Panel for the drawing -- implemented by a internal class
    private PainterCanvas drawingPanel ;
    
    // activeArtist is used by the internal classes
    private Painter activeArtist = null ;
    
    /**
     * Constructs a Painter MUX
     * @param width Width of panel on which paintings are displayed
     * @param height Height of panel in which paintings are displayed
     */
    public PainterMux(int width, int height) {
        numPainters = 0 ;
        objectButtonGroup = new javax.swing.ButtonGroup() ;
	objectButtonPanel = new javax.swing.JPanel() ;
	objectButtonPanel.setLayout(new java.awt.FlowLayout()) ;
        objectScrollBar = new javax.swing.JScrollPane(objectButtonPanel) ;
        objectScrollBar.setVerticalScrollBarPolicy(javax.swing.ScrollPaneConstants.VERTICAL_SCROLLBAR_NEVER) ;
        objectScrollBar.setHorizontalScrollBarPolicy(javax.swing.ScrollPaneConstants.HORIZONTAL_SCROLLBAR_ALWAYS) ;
	drawingPanel = new PainterCanvas(width, height) ;
	setLayout(new java.awt.BorderLayout()) ;
	add(objectScrollBar, java.awt.BorderLayout.NORTH) ;
	add(drawingPanel, java.awt.BorderLayout.CENTER) ;
    }
    
    /**
     * Add a painting to the MUX
     * @param plotObj Painter
     * @param plotNam used for radio button to select painting
     */
    public void addPainter(Painter plotObj, String plotNam) {
        final Painter PASSplotObj = plotObj ;
        final String  PASSplotNam = plotNam ;
        javax.swing.JRadioButton objectButton = new javax.swing.JRadioButton(plotNam, false) ;
        objectButton.addItemListener(new radioButtonHandler(plotObj)) ;
        objectButtonPanel.add(objectButton) ;
        objectButtonGroup.add(objectButton) ;
    }
    
    // This is the color as taken from www.unca.edu
    private static final java.awt.Color uncaBlue = new java.awt.Color(0x000066) ; 
    
    // Internal class for our single panel
    private class PainterCanvas extends javax.swing.JComponent {
        private java.awt.Dimension noGC = new java.awt.Dimension(0,0) ;
        
        PainterCanvas(int width, int height) {
            setBackground(uncaBlue) ;
            setPreferredSize(new java.awt.Dimension(width, height)) ;
        }
        
        public void paint(java.awt.Graphics g) {
            if (activeArtist != null) {
                java.awt.Dimension panelSize = getSize(noGC) ;
                activeArtist.paintCanvas(g.create(), drawingPanel) ;
            } else {
                super.paint(g) ;
            }
        }
        
    }
    
    // Internal class to choose a newly selected function
    private class radioButtonHandler implements java.awt.event.ItemListener {
        private Painter myArtist ;
        
        radioButtonHandler(Painter io) {
           myArtist = io ;
        }
        
        public void itemStateChanged( java.awt.event.ItemEvent e ) {
            activeArtist = myArtist ;
            repaint() ;
        }
    }

}
